instantMessage

# XMLRésuméLibrary: User Guide

history | Element Reference | institution

## Name

instantMessage — An instant message username or address

## Synopsis

### Content Model

    (#PCDATA)

### Attributes

Name | Type | Default
--- | --- | ---
service | CDATA | None
targets | CDATA | None

## Description

The `email` element contains a username or address that can be used to contact a person via an internet instant messaging service, such as AOL Instant Messenger (AIM) or Jabber.

### Parents

`instantMessage` may be contained in these elements: `contact`

### Attributes

`service`

  Specifies the service that the username or address is to be used with. Acceptable values are:

  `aim`

    AOL Instant Messenger

  `icq`

    ICQ

  `irc`

    Internet Relay Chat

  `jabber`

    Jabber

  `msn`

    MSN Messenger

  `yahoo`

    Yahoo! Messenger

## See Also

`email`.

## Examples

    <instantMessage service="yahoo">joesmith</instantMessage>

    <instantMessage service="aim">janedoe</instantMessage>

    <instantMessage service="jabber">sammybob@jabber.com</instantMessage>

history | Element Reference | institution